from sklearn.model_selection import train_test_split
import numpy as np
import pandas as pd
from sklearn.ensemble import RandomForestRegressor
from sklearn.metrics import r2_score,mean_squared_error,mean_absolute_percentage_error
from pprint import pprint
import matplotlib.pyplot as plt

dataset = np.genfromtxt('data.csv', delimiter=',', skip_header=1)
x = dataset[:,[0,1,2,4,5,6,7,8,9]]
y = dataset[:,3]
print(x)
x_train, x_test, y_train, y_test = train_test_split(x, y, test_size=0.25, random_state=42)

model = RandomForestRegressor(random_state=42)
model.fit(x_train,y_train)
pprint(model.get_params())

feature_list = ["StandortID","ZielortID","Entfernung","Jahr","Monat","Tag","Wochentag","Stunde","Minute"]
importances = np.round(model.feature_importances_ * 100,decimals=2)
zipped = list(zip(feature_list,importances))
pprint(zipped)

#plt.style.use('fivethirtyeight')
x_values = list(range(len(importances)))
plt.figure(figsize=(10,10))
plt.bar(x_values, importances, orientation = 'vertical')
plt.xticks(x_values, feature_list, rotation='vertical')
plt.ylabel('Importance'); plt.xlabel('Feature'); plt.title('Feature Analyse');
plt.show()

y_predict = model.predict(x_test)
accuracy = (1-mean_absolute_percentage_error(y_test, y_predict))*100
print("Accuracy: " + str(accuracy) + '%')